==> boostcrm-widget-1.0.2.tgz: package/es/store/actions/ws.actions.js <==
import _regeneratorRuntime from 'babel-runtime/regenerator';
import _extends from 'babel-runtime/helpers/extends';
import _asyncToGenerator from 'babel-runtime/helpers/asyncToGenerator';
import _get from 'lodash/get';
import { createAction } from 'redux-actions';
import { GROUP, TYPE } from '../../commons/constants/websocket';
import { getTenantInfo } from '../../commons/tenant-info';
import { sendMessage } from '../../connections/websocket';
import { MESSAGE_STATUS } from '../../commons/constants/message-status';

import { resetNumberOfNewMessages } from '../actions/message.actions';

export var receiveMessageFromAdmin = createAction('WS_' + GROUP.MESSAGE + '_' + TYPE.MESSAGE.NEW_MESSAGE_FROM_ADMIN);

export var receiveCreatedMessageNotification = createAction('WS_' + GROUP.MESSAGE + '_' + TYPE.MESSAGE.CREATED_MESSAGE);

export var receiveUpdateCallStatus = createAction('WS_' + GROUP.CALL + '_' + TYPE.CALL.RECEIVE_UPDATE_CALL_STATUS);

export var receiveICEServerResponse = createAction('WS_' + GROUP.CALL + '_' + TYPE.CALL.REQUEST_ICE_SERVERS_RES);

// Emit message status after received
export var sendAckReceivingMessage = function sendAckReceivingMessage(payload, channelId) {
  return function () {
    var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(dispatch, getState) {
      var showChat;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              // console.log('sendAckReceivingMessage: 1', payload, channelId);
              showChat = _get(getState(), 'behavior.showChat');

              if (document.hidden === false && showChat) {
                _sendMessage(_extends({}, payload, { status: MESSAGE_STATUS.READ }), getState(), channelId);
                dispatch(resetNumberOfNewMessages());
              } else {
                _sendMessage(_extends({}, payload, { status: MESSAGE_STATUS.DELIVERIED }), getState(), channelId);
                // Call function listen event visibilityChange
                _handleVisibilityChange(payload, getState(), channelId, dispatch);
              }

            case 2:
            case 'end':
              return _context.stop();
          }
        }
      }, _callee, this);
    }));

    return function (_x, _x2) {
      return _ref.apply(this, arguments);
    };
  }();
};

var _sendMessage = function _sendMessage(payload) {
  sendMessage({
    group: GROUP.MESSAGE,
    type: TYPE.MESSAGE.UPDATE_MESSAGE_STATUS,
    payload: payload,
    tenantInfo: getTenantInfo()
  });
};

var _handleVisibilityChange = function _handleVisibilityChange(payload, store, channelId, dispatch) {
  // console.log('_handleVisibilityChange', payload);
  var showChat = _get(store, 'behavior.showChat');
  function handleVisibilityChange() {
    if (!document.hidden && showChat) {
      _sendMessage(_extends({}, payload, { status: MESSAGE_STATUS.READ }), store, channelId);
      dispatch(resetNumberOfNewMessages());
    }
  }
  document.addEventListener('visibilitychange', handleVisibilityChange, {
    once: true
  });
};

==> boostcrm-widget-1.0.8.tgz: package/es/store/actions/ws.actions.js <==
import _extends from "@babel/runtime/helpers/extends";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _get from "lodash/get";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { createAction } from 'redux-actions';
import { GROUP, TYPE } from '../../commons/constants/websocket';
import { getTenantInfo } from '../../commons/tenant-info';
import { sendMessage } from '../../connections/websocket';
import { MESSAGE_STATUS } from '../../commons/constants/message-status';
import { resetNumberOfNewMessages } from '../actions/message.actions';
export var receiveMessageFromAdmin = createAction("WS_" + GROUP.MESSAGE + "_" + TYPE.MESSAGE.NEW_MESSAGE_FROM_ADMIN);
export var receiveCreatedMessageNotification = createAction("WS_" + GROUP.MESSAGE + "_" + TYPE.MESSAGE.CREATED_MESSAGE);
export var receiveUpdateCallStatus = createAction("WS_" + GROUP.CALL + "_" + TYPE.CALL.RECEIVE_UPDATE_CALL_STATUS);
export var receiveICEServerResponse = createAction("WS_" + GROUP.CALL + "_" + TYPE.CALL.REQUEST_ICE_SERVERS_RES); // Emit message status after received

export var sendAckReceivingMessage = function sendAckReceivingMessage(payload, channelId) {
  return /*#__PURE__*/function () {
    var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(dispatch, getState) {
      var showChat;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              // console.log('sendAckReceivingMessage: 1', payload, channelId);
              showChat = _get(getState(), 'behavior.showChat');

              if (document.hidden === false && showChat) {
                _sendMessage(_extends({}, payload, {
                  status: MESSAGE_STATUS.READ
                }), getState(), channelId);

                dispatch(resetNumberOfNewMessages());
              } else {
                _sendMessage(_extends({}, payload, {
                  status: MESSAGE_STATUS.DELIVERIED
                }), getState(), channelId); // Call function listen event visibilityChange


                _handleVisibilityChange(payload, getState(), channelId, dispatch);
              }

            case 2:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    }));

    return function (_x, _x2) {
      return _ref.apply(this, arguments);
    };
  }();
};

var _sendMessage = function _sendMessage(payload) {
  sendMessage({
    group: GROUP.MESSAGE,
    type: TYPE.MESSAGE.UPDATE_MESSAGE_STATUS,
    payload: payload,
    tenantInfo: getTenantInfo()
  });
};

var _handleVisibilityChange = function _handleVisibilityChange(payload, store, channelId, dispatch) {
  // console.log('_handleVisibilityChange', payload);
  var showChat = _get(store, 'behavior.showChat');

  function handleVisibilityChange() {
    if (!document.hidden && showChat) {
      _sendMessage(_extends({}, payload, {
        status: MESSAGE_STATUS.READ
      }), store, channelId);

      dispatch(resetNumberOfNewMessages());
    }
  }

  document.addEventListener('visibilitychange', handleVisibilityChange, {
    once: true
  });
};
